@@ -12,21 +12,27 @@ class WebhookTestingGateway(object):
         self.gateway = gateway
         self.config = gateway.config
 
-    def sample_notification(self, kind, id):
-        payload = encodebytes(self.__sample_xml(kind, id))
+    def sample_notification(self, kind, id, source_merchant_id=None):
+        payload = encodebytes(self.__sample_xml(kind, id, source_merchant_id))
         hmac_payload = Crypto.sha1_hmac_hash(self.gateway.config.private_key, payload)
         signature = "%s|%s" % (self.gateway.config.public_key, hmac_payload)
         return {'bt_signature': signature, 'bt_payload': payload}
 
-    def __sample_xml(self, kind, id):
+    def __sample_xml(self, kind, id, source_merchant_id):
         timestamp = datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%SZ")
+
+        source_merchant_id_xml = ''
+        if source_merchant_id is not None:
+            source_merchant_id_xml = '<source-merchant-id>%s</source-merchant-id>' % source_merchant_id
+
         sample_xml = """
             <notification>
                 <timestamp type="datetime">%s</timestamp>
                 <kind>%s</kind>
+                %s
                 <subject>%s</subject>
             </notification>
-        """ % (timestamp, kind, self.__subject_sample_xml(kind, id))
+        """ % (timestamp, kind, source_merchant_id_xml, self.__subject_sample_xml(kind, id))
         return sample_xml.encode('utf-8')
 
     def __subject_sample_xml(self, kind, id):
@@ -52,6 +58,8 @@ class WebhookTestingGateway(object):
             return self.__partner_merchant_disconnected_sample_xml()
         elif kind == WebhookNotification.Kind.PartnerMerchantDeclined:
             return self.__partner_merchant_declined_sample_xml()
+        elif kind == WebhookNotification.Kind.OAuthAccessRevoked:
+            return self.__oauth_access_revocation_sample_xml(id)
         elif kind == WebhookNotification.Kind.DisbursementException:
             return self.__disbursement_exception_sample_xml(id)
         elif kind == WebhookNotification.Kind.Disbursement:
@@ -528,6 +536,14 @@ class WebhookTestingGateway(object):
             </partner-merchant>
             """
 
+    def __oauth_access_revocation_sample_xml(self, id):
+        return """
+            <oauth-application-revocation>
+                <merchant-id>%s</merchant-id>
+                <oauth-application-client-id>oauth_application_client_id</oauth-application-client-id>
+            </oauth-application-revocation>
+            """ % id
+
     def __account_updater_daily_report_sample_xml(self):
         return """
             <account-updater-daily-report>
